@@ -12,9 +12,10 @@ created 27-may-2019 by richb@instantlinux.net
 """
 
 from flask import g
-from datetime import datetime, timedelta
+from datetime import timedelta
 
 from .access import AccessControl
+from . import utils
 
 GRANTS = {}
 
@@ -38,17 +39,16 @@ class Grants(object):
             raise AttributeError('Unknown grant %s' % name)
         if not uid:
             uid = AccessControl().uid
-        if uid not in GRANTS or datetime.utcnow() > GRANTS[uid]['expires']:
+        if uid not in GRANTS or utils.utcnow() > GRANTS[uid]['expires']:
             records = self.session.query(self.models.Grant).filter_by(
                 uid=uid).all()
-            grants = dict(expires=datetime.utcnow() + timedelta(
-                seconds=self.ttl))
+            grants = dict(expires=utils.utcnow() + timedelta(seconds=self.ttl))
             for record in records:
                 grants[record.name] = record.value
                 if record.expires:
                     grants['expires'] = min(record.expires, grants['expires'])
             GRANTS[uid] = grants
-        if name in GRANTS[uid] and datetime.utcnow() < GRANTS[uid]['expires']:
+        if name in GRANTS[uid] and utils.utcnow() < GRANTS[uid]['expires']:
             return GRANTS[uid][name]
         return GRANTS['defaults'][name]
 
